@@ -9,7 +9,7 @@ import sys
 import threading
 from ast import PyCF_ONLY_AST
 from inspect import Parameter
-from typing import Dict, Iterator, List, Optional, Tuple
+from typing import Any, Callable, Dict, Iterator, List, Optional, Tuple
 
 import docstring_to_markdown
 import jedi.api.errors
@@ -37,25 +37,35 @@ from pygls.workspace import Document
 from .initialization_options import HoverDisableOptions, InitializationOptions
 from .type_map import get_lsp_completion_type, get_lsp_symbol_type
 
+if sys.version_info < (3, 10):
+    from typing_extensions import ParamSpec
+else:
+    from typing import ParamSpec
 
-def debounce(interval_s, keyed_by=None):
+
+P = ParamSpec("P")
+
+
+def debounce(
+    interval_s: int, keyed_by: Optional[str] = None
+) -> Callable[[Callable[P, None]], Callable[P, None]]:
     """Debounce calls to this function until interval_s seconds have passed.
 
     Decorator copied from https://github.com/python-lsp/python-lsp-
     server
     """
 
-    def wrapper(func):
-        timers = {}
+    def wrapper(func: Callable[P, None]) -> Callable[P, None]:
+        timers: Dict[Any, threading.Timer] = {}
         lock = threading.Lock()
 
         @functools.wraps(func)
-        def debounced(*args, **kwargs):
+        def debounced(*args: P.args, **kwargs: P.kwargs) -> None:
             sig = inspect.signature(func)
             call_args = sig.bind(*args, **kwargs)
             key = call_args.arguments[keyed_by] if keyed_by else None
 
-            def run():
+            def run() -> None:
                 with lock:
                     del timers[key]
                 return func(*args, **kwargs)
@@ -298,7 +308,7 @@ def lsp_python_diagnostic(uri: str, source: str) -> Optional[Diagnostic]:
         until_column = (
             _until_column - 1 if _until_column is not None else column + 1
         )
-        until_line = _until_line - 1 if _until_line is not None else line + 1
+        until_line = _until_line - 1 if _until_line is not None else line
 
         if (line, column) >= (until_line, until_column):
             until_column, until_line = column, line
@@ -318,8 +328,8 @@ def lsp_python_diagnostic(uri: str, source: str) -> Optional[Diagnostic]:
 def line_column(position: Position) -> Tuple[int, int]:
     """Translate pygls Position to Jedi's line/column.
 
-    Returns a dictionary because this return result should be unpacked as a
-    function argument to Jedi's functions.
+    Returns a tuple because this return result should be unpacked as a function
+    argument to Jedi's functions.
 
     Jedi is 1-indexed for lines and 0-indexed for columns. LSP is 0-indexed for
     lines and 0-indexed for columns. Therefore, add 1 to LSP's request for the
@@ -342,19 +352,19 @@ def line_column(position: Position) -> Tuple[int, int]:
 def line_column_range(pygls_range: Range) -> Dict[str, int]:
     """Translate pygls range to Jedi's line/column/until_line/until_column.
 
-    Returns a dictionary because this return result should be unpacked as a
-    function argument to Jedi's functions.
+    Returns a dictionary because this return result should be unpacked
+    as a function argument to Jedi's functions.
 
-    Jedi is 1-indexed for lines and 0-indexed for columns. LSP is 0-indexed for
-    lines and 0-indexed for columns. Therefore, add 1 to LSP's request for the
-    line.
+    Jedi is 1-indexed for lines and 0-indexed for columns. LSP is
+    0-indexed for lines and 0-indexed for columns. Therefore, add 1 to
+    LSP's request for the line.
     """
-    return dict(
-        line=pygls_range.start.line + 1,
-        column=pygls_range.start.character,
-        until_line=pygls_range.end.line + 1,
-        until_column=pygls_range.end.character,
-    )
+    return {
+        "line": pygls_range.start.line + 1,
+        "column": pygls_range.start.character,
+        "until_line": pygls_range.end.line + 1,
+        "until_column": pygls_range.end.character,
+    }
 
 
 def compare_names(name1: Name, name2: Name) -> bool:
@@ -371,12 +381,12 @@ def compare_names(name1: Name, name2: Name) -> bool:
 def complete_sort_name(name: Completion, append_text: str) -> str:
     """Return sort name for a jedi completion.
 
-    Should be passed to the sortText field in CompletionItem. Strings sort a-z,
-    a comes first and z comes last.
+    Should be passed to the sortText field in CompletionItem. Strings
+    sort a-z, a comes first and z comes last.
 
-    Additionally, we'd like to keep the sort order to what Jedi has provided.
-    For this reason, we make sure the sort-text is just a letter and not the
-    name itself.
+    Additionally, we'd like to keep the sort order to what Jedi has
+    provided. For this reason, we make sure the sort-text is just a
+    letter and not the name itself.
     """
     name_str = name.name
     if name_str is None:
