@@ -4,40 +4,11 @@ Helper functions that simplify working with pygls
 """
 
 
-import functools
 from typing import Optional
 
-from pygls.types import Position, Range
+from lsprotocol.types import Position, Range
 from pygls.workspace import Document
 
-_SENTINEL = object()
-
-
-def rgetattr(obj: object, attr: str, default: object = None) -> object:
-    """Get nested attributes, recursively.
-
-    Usage:
-        >> repr(my_object)
-            Object(hello=Object(world=2))
-        >> rgetattr(my_object, "hello.world")
-            2
-        >> rgetattr(my_object, "hello.world.space")
-            None
-        >> rgetattr(my_object, "hello.world.space", 20)
-            20
-    """
-    result = _rgetattr(obj, attr)
-    return default if result is _SENTINEL else result
-
-
-def _rgetattr(obj: object, attr: str) -> object:
-    """Get nested attributes, recursively."""
-
-    def _getattr(obj: object, attr: str) -> object:
-        return getattr(obj, attr, _SENTINEL)
-
-    return functools.reduce(_getattr, [obj] + attr.split("."))  # type: ignore
-
 
 def char_before_cursor(
     document: Document, position: Position, default: str = ""
